@@ -5,11 +5,13 @@ from matplotlib import pyplot as plt
 import io
 import sys
 import base64
+import atexit
 
 sio = socketio.Client()
 task_id = None
 # target log for where intercepted logs should be forwarded to
 logging_target = None
+timeout_target = 5
 
 timeout_count = 0
 
@@ -27,12 +29,16 @@ cmap: str = "gray"):
     my_base64_jpgData = base64.b64encode(my_stringIObytes.read()).decode()
     return my_base64_jpgData
 
+def exit_handler():
+    disconnect()
+                    
 # https://stackoverflow.com/a/51981833
 def vsui_process():
     def decorator(func):
         def wrapper(*args, **kwargs):
             r = None
             try:
+                atexit.register(exit_handler)
                 r = func(*args, **kwargs)
             except Exception as e:
                 r = disconnect()
@@ -43,13 +49,15 @@ def vsui_process():
 
 def safe_emit(event, data):
     ''' emit a socketio event with exception handling '''
-    global timeout_count
+    global timeout_count, timeout_target
     try:
         sio.emit(event, data)
         timeout_count = 0
     except:
+        logging.warning(f'timeout {timeout_count} / {timeout_target}')
         timeout_count += 1
-        if timeout_count == 5:
+        if timeout_count == timeout_target:
+            logging.error(f'socketio timeout, exiting!')
             disconnect()
             sys.exit(1)
 
